@@ -1,7 +1,7 @@
 # ==============================================================================
 # imputation function for fixed variable
 # ==============================================================================
-mi.fixed <- function( formula, data = NULL, ... ) {
+mi.fixed <- function( formula, data = NULL, missing.index = NULL,  ... ) {
   call <- match.call()
   mf   <- match.call(expand.dots = FALSE)
   m    <- match(c("formula", "data"), names(mf), 0)
@@ -20,26 +20,34 @@ mi.fixed <- function( formula, data = NULL, ... ) {
     }
   }
   X <- mf[,-1,drop=FALSE]
-  namesD <- if( is.null( data ) ) { 
-              NULL 
-            } 
-            else { 
-              deparse( substitute( data ) )
-            }
-  nameY <- deparse( substitute( Y ) )
-  mis   <- is.na( Y )
-  n.mis <- sum ( mis )
+#  namesD <- if( is.null( data ) ) { 
+#              NULL 
+#            } 
+#            else { 
+#              deparse( substitute( data ) )
+#            }
+#  nameY <- deparse( substitute( Y ) )
+
+  mis <- is.na(Y)
+  n.mis <- if(is.null(missing.index)){
+             sum(mis)
+           } else{
+             length(missing.index)
+           }
+  if(is.null(missing.index)& any(mis)){
+    missing.index <- mis
+  }
+
   y.level <-  if ( is.numeric( Y ) ) {
                 sort( unique ( Y ) )
-              } 
-              else {
+              } else {
                 levels( factor( Y ) )
               }
   # main program
   fixd.imp    <- y.level
   determ.pred <- rep( y.level, length( Y ) )
   names( determ.pred ) <- 1:length( determ.pred )
-  random.pred <- determ.pred[is.na(Y)]
+  random.pred <- determ.pred[missing.index]
   result <- new(c("mi.fixed", "mi.method"),
               model = vector("list", 0),
               expected = numeric(0), 
@@ -47,22 +55,26 @@ mi.fixed <- function( formula, data = NULL, ... ) {
   result@model$call    <- ""
   result@expected <- determ.pred
   result@random   <- random.pred
-  return( result )
+  return(result)
   on.exit(rm(fixd.imp))
 }
 
-mi.copy <- function(Y, X, ... ) {
+mi.copy <- function(Y, X, missing.index = NULL, ... ) {
 #  fit <- lm(Y ~ unlist(X))
 #  rho <- coef(fit)[2]
-  nameY <- deparse(substitute(Y))
-  nameX <- deparse(substitute(X))
-  mis   <- is.na(Y)
-  n.mis <- sum(mis)
+#  nameY <- deparse(substitute(Y))
+#  nameX <- deparse(substitute(X))
+  mis <- is.na(Y)
+  n.mis <- if(is.null(missing.index)){
+             sum(mis)
+           } else{
+             length(missing.index)
+           }
   # main program
-  fixd.imp    <- nameX
+  #fixd.imp    <- nameX
   determ.pred <- unlist(X)
   names( determ.pred ) <- 1:length( determ.pred )
-  random.pred <- determ.pred[mis] #* rho
+  random.pred <- determ.pred[missing.index] #* rho
   # return the result
   result <- new(c("mi.fixed", "mi.method"),
               model = vector("list", 0),
@@ -71,5 +83,5 @@ mi.copy <- function(Y, X, ... ) {
   result@expected <- determ.pred #* rho
   result@random   <- random.pred
   return( result )
-  on.exit(rm(fixd.imp))
+#  on.exit(rm(fixd.imp))
 }
